Learn R Programming

shinyfa (version 0.0.1)

analyze_shiny_reactivity: Analyze Shiny server reactivity in a given file

Description

This function processes a Shiny server script, identifying render functions, their reactivity types, and any input dependencies.

Usage

analyze_shiny_reactivity(file_path)

Value

A data frame summarizing the reactivity structure of the file.

Arguments

file_path

A string representing the path to the R file.