Learn R Programming

shinyfa (version 0.0.1)

read_shiny_file: Read a Shiny file and determine if it should be skipped

Description

This function reads a Shiny server file and checks whether it only contains source() calls or is empty. If so, it returns NULL to indicate the file should be skipped.

Usage

read_shiny_file(file_path)

Value

A character vector containing the file's lines if valid, otherwise NULL.

Arguments

file_path

A string representing the path to the R file.